@@ -310,6 +310,9 @@ sub _issue {
 		"ContactNumberAlt" => undef,
 		"WorksAuthorisationLimit" => undef,
 		"ExternalRefTenancyAgreement" => undef,
+		"AssignedAgent" => undef,
+		"Block" => undef,
+		"ExternalRefTenancyAgreement" => undef,
 		"FaultPriority" => 3,
 		"TenantId" => "$id",
 		"Job" => undef,
